var fs = require("fs");
var path = require('path');
var Handlebars = require("handlebars");

function render(resume) {
	var css = fs.readFileSync(__dirname + "/style.css", "utf-8");
	var tpl = fs.readFileSync(__dirname + "/resume.hbs", "utf-8");

	var partialsDir = path.join(__dirname, 'partials');
	var filenames = fs.readdirSync(partialsDir);
	filenames.forEach(function (filename) {
	  var matches = /^([^.]+).hbs$/.exec(filename);
	  if (!matches) {
	    return;
	  }
	  var name = matches[1];
	  var filepath = path.join(partialsDir, filename);
	  var template = fs.readFileSync(filepath, 'utf8');
	  Handlebars.registerPartial(name, template);
	});

  Handlebars.registerHelper('icon', iconHtml);
  Handlebars.registerHelper('year-month', shortenDateYearMonth);

	return Handlebars.compile(tpl)({
		css: css,
		resume: resume
	});
}

function iconHtml(iconName) {
  let classes = '';
  switch (iconName) {
      case 'Twitter':
          return fontAwesomeHtml("fa-brands fa-twitter");
    case 'SoundCloud':
        return fontAwesomeHtml("fa-brands fa-soundcloud");
    case 'GitHub':
      return fontAwesomeHtml("fa-brands fa-github");
    case 'Mastodon':
      return fontAwesomeHtml("fa-brands fa-mastodon");
    case 'Stack Overflow':
        return fontAwesomeHtml("fa-brands fa-stack-overflow");
    case 'Wikipedia':
        return fontAwesomeHtml("fa-brands fa-wikipedia-w");
    case 'LinkedIn':
        return fontAwesomeHtml("fa-brands fa-linkedin");
    case 'Education':
      return fontAwesomeHtml("fa-solid fa-graduation-cap");
    case 'Hammer':
      return fontAwesomeHtml("fa-solid fa-hammer");
    case 'Language':
      return fontAwesomeHtml("fa-solid fa-language");
    case 'Lightbulb':
      return fontAwesomeHtml("fa-solid fa-lightbulb");
    case 'Paragraph':
        return fontAwesomeHtml("fa-solid fa-paragraph");
    case 'Briefcase':
        return fontAwesomeHtml("fa-solid fa-briefcase");
    case 'Handshake':
        return fontAwesomeHtml("fa-solid fa-handshake-angle");
    case 'Award':
        return fontAwesomeHtml("fa-solid fa-award");
    case 'Flask':
          return fontAwesomeHtml("fa-solid fa-flask");
    case 'English':
      return "🇬🇧";
    case "German":
      return "🇩🇪";
    case "French":
      return "🇫🇷";
    default:
      console.warn("Could not fine icon: ", iconName);
      return fontAwesomeHtml('fa-solid fa-file');
  }
}

function fontAwesomeHtml(classes) {
    return new Handlebars.SafeString(`<i class="${classes}"></i>`);
}




function shortenDateYearMonth(date) {
    return date.substring(0, 7);
}

module.exports = {
	render: render
};
